@@ -1,6 +1,6 @@
 from peerplays.instance import BlockchainInstance
 from .exceptions import BettingMarketDoesNotExistException
-from .blockchainobject import BlockchainObject, ObjectCache
+from .blockchainobject import BlockchainObject, BlockchainObjects
 
 
 class BettingMarket(BlockchainObject):
@@ -11,11 +11,13 @@ class BettingMarket(BlockchainObject):
             accesing a RPC
 
     """
-    type_id = 21
+
+    type_id = 25
 
     def refresh(self):
-        assert self.identifier[:5] == "1.21.",\
-            "Identifier needs to be of form '1.21.xx'"
+        assert (
+            self.identifier[:5] == "1.25."
+        ), "Identifier needs to be of form '1.25.xx'"
         data = self.blockchain.rpc.get_object(self.identifier)
         if not data:
             raise BettingMarketDoesNotExistException(self.identifier)
@@ -25,27 +27,30 @@ class BettingMarket(BlockchainObject):
     @property
     def bettingmarketgroup(self):
         from .bettingmarketgroup import BettingMarketGroup
+
         return BettingMarketGroup(self["group_id"])
 
 
-class BettingMarkets(list, BlockchainInstance):
+class BettingMarkets(BlockchainObjects, BlockchainInstance):
     """ List of all available BettingMarkets
 
-        :param str betting_market_group_id: Market Group ID (``1.20.xxx``)
+        :param str betting_market_group_id: Market Group ID (``1.24.xxx``)
     """
-    cache = ObjectCache()
 
     def __init__(self, betting_market_group_id, *args, **kwargs):
+        self.betting_market_group_id = betting_market_group_id
         BlockchainInstance.__init__(self, *args, **kwargs)
+        BlockchainObjects.__init__(self, betting_market_group_id, *args, **kwargs)
 
-        if betting_market_group_id in BettingMarkets.cache:
-            self.bettingmarkets = BettingMarkets.cache[betting_market_group_id]
-        else:
-            self.bettingmarkets = self.blockchain.rpc.list_betting_markets(
-                betting_market_group_id)
-            BettingMarkets.cache[betting_market_group_id] = self.bettingmarkets
+    def refresh(self, *args, **kwargs):
 
-        super(BettingMarkets, self).__init__([
-            BettingMarket(x, lazy=False, blockchain_instance=self.blockchain)
-            for x in self.bettingmarkets
-        ])
+        self.bettingmarkets = self.blockchain.rpc.list_betting_markets(
+            self.betting_market_group_id
+        )
+        self.store(
+            [
+                BettingMarket(x, lazy=False, blockchain_instance=self.blockchain)
+                for x in self.bettingmarkets
+            ],
+            self.betting_market_group_id,
+        )
