@@ -1,6 +1,6 @@
 from .instance import BlockchainInstance
 from .exceptions import SportDoesNotExistException
-from .blockchainobject import BlockchainObject, ObjectCache
+from .blockchainobject import BlockchainObject, BlockchainObjects
 
 
 class Sport(BlockchainObject):
@@ -11,7 +11,8 @@ class Sport(BlockchainObject):
             accesing a RPC
 
     """
-    type_id = 16
+
+    type_id = 20
 
     def refresh(self):
         data = self.blockchain.rpc.get_object(self.identifier)
@@ -22,24 +23,28 @@ class Sport(BlockchainObject):
     @property
     def eventgroups(self):
         from .eventgroup import EventGroups
+
         return EventGroups(self["id"])
 
 
-class Sports(list):
+class Sports(BlockchainObjects, BlockchainInstance):
     """ List of all available sports
     """
-    cache = ObjectCache()
 
-    def __init__(self, **kwargs):
-        BlockchainInstance.__init__(self, **kwargs)
+    def __init__(self, *args, **kwargs):
+        super().__init__(self, *args, **kwargs)
 
-        if "sports" in Sports.cache:
-            self.sports = Sports.cache["sports"]
-        else:
-            self.sports = self.blockchain.rpc.list_sports()
-            Sports.cache["sports"] = self.sports
+    def refresh(self, *args, **kargs):
+        self._sports = self.blockchain.rpc.list_sports()
+        self.store(
+            [
+                Sport(x, lazy=False, blockchain_instance=self.blockchain)
+                for x in self._sports
+            ]
+        )
 
-        super(Sports, self).__init__([
-            Sport(x, lazy=False, blockchain_instance=self.blockchain)
-            for x in self.sports
-        ])
+    @property
+    def sports(self):
+        """ DEPRECATED
+        """
+        return list(self)
