@@ -15,6 +15,10 @@ ts = [
     "vesting_balance",
     "worker",
     "balance",
+    "tournament",
+    "tournament_details",
+    "match",
+    "game",
     "sport",
     "event_group",
     "event",
@@ -22,10 +26,8 @@ ts = [
     "betting_market_group",
     "betting_market",
     "bet",
-    "tournament",
-    "tournament_details",
-    "match",
-    "game",
+    "custom_permission",
+    "custom_account_authority",
 ]
 
 object_type = {k: ts.index(k) for k in ts}
